@@ -18,11 +18,13 @@
 
 #pragma once
 
+#include "nautilus-types.h"
+
+#include <adwaita.h>
 #include <glib.h>
 #include <glib/gprintf.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include "nautilus-files-view.h"
 
 G_BEGIN_DECLS
 
@@ -209,24 +211,24 @@ static const TagConstants numbering_tags_constants[] =
 typedef struct
 {
     gchar *name;
-    gint index;
+    guint index;
 } ConflictData;
 
 typedef struct {
-    GString *file_name;
+    NautilusFile *file;
     GString *metadata [G_N_ELEMENTS (metadata_tags_constants)];
 } FileMetadata;
 
 #define NAUTILUS_TYPE_BATCH_RENAME_DIALOG (nautilus_batch_rename_dialog_get_type())
 
-G_DECLARE_FINAL_TYPE (NautilusBatchRenameDialog, nautilus_batch_rename_dialog, NAUTILUS, BATCH_RENAME_DIALOG, AdwWindow);
+G_DECLARE_FINAL_TYPE (NautilusBatchRenameDialog, nautilus_batch_rename_dialog, NAUTILUS, BATCH_RENAME_DIALOG, AdwDialog);
 
 GtkWidget*      nautilus_batch_rename_dialog_new                      (GList                     *selection,
-                                                                       NautilusDirectory         *directory,
                                                                        GtkRoot                   *window);
 
 void            nautilus_batch_rename_dialog_query_finished           (NautilusBatchRenameDialog *dialog,
                                                                        GHashTable                *hash_table,
-                                                                       GList                     *selection_metadata);
+                                                                       GHashTable                *selection_metadata,
+                                                                       gboolean                   has_metadata[]);
 
 G_END_DECLS
