@@ -10,8 +10,9 @@
 
 #pragma once
 
+#include "nautilus-types.h"
+
 #include <gtk/gtk.h>
-#include "nautilus-file.h"
 
 #define HOVER_TIMEOUT 500
 
@@ -20,7 +21,12 @@
 GdkDragAction      nautilus_drag_drop_action_ask                 (GtkWidget        *widget,
                                                                   GdkDragAction     possible_actions);
 
-GdkDragAction      nautilus_dnd_get_preferred_action              (NautilusFile     *target_file,
-                                                                   GFile            *dropped);
+GdkDragAction      nautilus_dnd_get_preferred_action             (NautilusFile     *target_file,
+                                                                  GFile            *dropped);
 GdkPaintable *     get_paintable_for_drag_selection              (GList            *selection,
                                                                   int               scale);
+
+gboolean           nautilus_dnd_perform_drop                     (NautilusFilesView *view,
+                                                                  const GValue      *value,
+                                                                  GdkDragAction      action,
+                                                                  GFile             *target_location);
