@@ -90,3 +90,30 @@ typedef enum
     NAUTILUS_OPEN_FLAG_NEW_TAB          = 1 << 2,
     NAUTILUS_OPEN_FLAG_DONT_MAKE_ACTIVE = 1 << 3,
 } NautilusOpenFlags;
+
+typedef enum {
+    NAUTILUS_SEARCH_TIME_TYPE_LAST_ACCESS = 0,
+    NAUTILUS_SEARCH_TIME_TYPE_LAST_MODIFIED,
+    NAUTILUS_SEARCH_TIME_TYPE_CREATED,
+} NautilusSearchTimeType;
+
+typedef enum {
+  NAUTILUS_SIDEBAR_ROW_INVALID = 0,
+  NAUTILUS_SIDEBAR_ROW_BUILT_IN,
+  NAUTILUS_SIDEBAR_ROW_EXTERNAL_MOUNT,
+  NAUTILUS_SIDEBAR_ROW_INTERNAL_MOUNT,
+  NAUTILUS_SIDEBAR_ROW_NEW_BOOKMARK,
+  NAUTILUS_SIDEBAR_ROW_BOOKMARK,
+  NAUTILUS_SIDEBAR_ROW_BOOKMARK_PLACEHOLDER,
+  NAUTILUS_SIDEBAR_N_ROW_TYPES
+} NautilusSidebarRowType;
+
+/* Keep order, since it's used for the sort functions */
+typedef enum {
+  NAUTILUS_SIDEBAR_SECTION_INVALID = 0,
+  NAUTILUS_SIDEBAR_SECTION_DEFAULT_LOCATIONS,
+  NAUTILUS_SIDEBAR_SECTION_BOOKMARKS,
+  NAUTILUS_SIDEBAR_SECTION_CLOUD,
+  NAUTILUS_SIDEBAR_SECTION_MOUNTS,
+  NAUTILUS_SIDEBAR_N_SECTION_TYPES
+} NautilusSidebarSectionType;
