@@ -1463,6 +1463,7 @@ starred_redo_func (NautilusFileUndoInfo           *info,
                                          G_OBJECT (info),
                                          self->files,
                                          on_undo_starred_tags_updated,
+                                         NULL,
                                          NULL);
     }
     else
@@ -1471,6 +1472,7 @@ starred_redo_func (NautilusFileUndoInfo           *info,
                                            G_OBJECT (info),
                                            self->files,
                                            on_undo_starred_tags_updated,
+                                           NULL,
                                            NULL);
     }
 }
@@ -1488,6 +1490,7 @@ starred_undo_func (NautilusFileUndoInfo           *info,
                                            G_OBJECT (info),
                                            self->files,
                                            on_undo_starred_tags_updated,
+                                           NULL,
                                            NULL);
     }
     else
@@ -1496,6 +1499,7 @@ starred_undo_func (NautilusFileUndoInfo           *info,
                                          G_OBJECT (info),
                                          self->files,
                                          on_undo_starred_tags_updated,
+                                         NULL,
                                          NULL);
     }
 }
@@ -1750,7 +1754,8 @@ trash_retrieve_files_to_restore_thread (GTask        *task,
         const char *origpath;
         GFile *origfile;
 
-        while ((info = g_file_enumerator_next_file (enumerator, NULL, &error)) != NULL)
+        while (g_file_enumerator_iterate (enumerator, &info, NULL, NULL, &error) &&
+               info != NULL)
         {
             /* Retrieve the original file uri */
             origpath = g_file_info_get_attribute_byte_string (info, G_FILE_ATTRIBUTE_TRASH_ORIG_PATH);
