@@ -34,23 +34,16 @@
 #include "nautilus-search-directory.h"
 #include "nautilus-starred-directory.h"
 #include "nautilus-ui-utilities.h"
-#include <fcntl.h>
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
 #include <gio/gio.h>
 #include <unistd.h>
 #include <stdlib.h>
-#include <sys/vfs.h>
 
 #define NAUTILUS_USER_DIRECTORY_NAME "nautilus"
 #define DEFAULT_NAUTILUS_DIRECTORY_MODE (0755)
 
-/* From linux/magic.h */
-#ifndef AUTOFS_SUPER_MAGIC
-#define AUTOFS_SUPER_MAGIC 0x0187
-#endif
-
 char *
 nautilus_compute_title_for_location (GFile *location)
 {
@@ -465,21 +458,18 @@ nautilus_file_list_from_uri_list (GList *uris)
     return g_list_reverse (result);
 }
 
-static GList *
-locations_from_file_list (GList *file_list)
+GList *
+nautilus_location_list_from_file_list (GList *files)
 {
-    NautilusFile *file;
-    GList *l, *ret;
+    GList *locations = NULL;
 
-    ret = NULL;
-
-    for (l = file_list; l != NULL; l = l->next)
+    for (GList *l = files; l != NULL; l = l->next)
     {
-        file = NAUTILUS_FILE (l->data);
-        ret = g_list_prepend (ret, nautilus_file_get_location (file));
+        NautilusFile *file = l->data;
+        locations = g_list_prepend (locations, nautilus_file_get_location (file));
     }
 
-    return g_list_reverse (ret);
+    return g_list_reverse (locations);
 }
 
 typedef struct
@@ -505,7 +495,7 @@ ensure_dirs_task_ready_cb (GObject      *_source,
         original_dir_location = nautilus_file_get_location (original_dir);
 
         files = g_hash_table_lookup (data->original_dirs_hash, original_dir);
-        locations = locations_from_file_list (files);
+        locations = nautilus_location_list_from_file_list (files);
 
         nautilus_file_operations_move_async (locations,
                                              original_dir_location,
@@ -1039,55 +1029,6 @@ nautilus_file_can_rename_files (GList *files)
     return TRUE;
 }
 
-NautilusQueryRecursive
-location_settings_search_get_recursive (void)
-{
-    switch (g_settings_get_enum (nautilus_preferences, "recursive-search"))
-    {
-        case NAUTILUS_SPEED_TRADEOFF_ALWAYS:
-        {
-            return NAUTILUS_QUERY_RECURSIVE_ALWAYS;
-        }
-        break;
-
-        case NAUTILUS_SPEED_TRADEOFF_LOCAL_ONLY:
-        {
-            return NAUTILUS_QUERY_RECURSIVE_LOCAL_ONLY;
-        }
-        break;
-
-        case NAUTILUS_SPEED_TRADEOFF_NEVER:
-        {
-            return NAUTILUS_QUERY_RECURSIVE_NEVER;
-        }
-        break;
-    }
-
-    return NAUTILUS_QUERY_RECURSIVE_ALWAYS;
-}
-
-NautilusQueryRecursive
-location_settings_search_get_recursive_for_location (GFile *location)
-{
-    NautilusQueryRecursive recursive = location_settings_search_get_recursive ();
-
-    g_return_val_if_fail (location, recursive);
-
-    if (recursive == NAUTILUS_QUERY_RECURSIVE_LOCAL_ONLY)
-    {
-        g_autoptr (NautilusFile) file = nautilus_file_get_existing (location);
-
-        g_return_val_if_fail (file != NULL, recursive);
-
-        if (nautilus_file_is_remote (file))
-        {
-            recursive = NAUTILUS_QUERY_RECURSIVE_NEVER;
-        }
-    }
-
-    return recursive;
-}
-
 /* check_schema_available() was copied from GNOME Settings */
 gboolean
 check_schema_available (const gchar *schema_id)
@@ -1140,35 +1081,3 @@ is_external_volume (GVolume *volume)
 
     return is_external;
 }
-
-/* Checks if the location is an autofs mountpoint without triggering mount.*/
-gboolean
-nautilus_location_is_autofs_mountpoint (GFile *location)
-{
-    g_return_val_if_fail (G_IS_FILE (location), FALSE);
-
-    g_autofree char *path = g_file_get_path (location);
-    struct statfs buf;
-    gint fd;
-
-    if (path == NULL)
-    {
-        return FALSE;
-    }
-
-    fd = g_open (path, O_PATH | O_NOFOLLOW, 0);
-    if (fd < 0)
-    {
-        return FALSE;
-    }
-
-    if (fstatfs (fd, &buf) < 0)
-    {
-        close (fd);
-        return FALSE;
-    }
-
-    close (fd);
-
-    return (buf.f_type == AUTOFS_SUPER_MAGIC);
-}
