@@ -27,8 +27,6 @@
 
 #include <config.h>
 
-#include "nautilus-query.h"
-
 #define NAUTILUS_DESKTOP_ID APPLICATION_ID ".desktop"
 
 /* These functions all return something something that needs to be
@@ -128,10 +126,8 @@ gboolean nautilus_file_can_rename_files (GList *files);
 
 GList * nautilus_file_list_from_uri_list (GList *uris);
 
-NautilusQueryRecursive location_settings_search_get_recursive (void);
-NautilusQueryRecursive location_settings_search_get_recursive_for_location (GFile *location);
-
 gboolean check_schema_available (const gchar *schema_id);
 gboolean is_external_volume (GVolume *volume);
 
-gboolean nautilus_location_is_autofs_mountpoint (GFile *location);
+GList *
+nautilus_location_list_from_file_list (GList *files);
