@@ -4,12 +4,15 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
+#include "nautilus-label-cell.h"
+
 /* Needed for NautilusColumn (full GType). */
 #include <nautilus-extension.h>
 
-#include "nautilus-label-cell.h"
-
+#include "nautilus-column.h"
+#include "nautilus-file.h"
 #include "nautilus-global-preferences.h"
+#include "nautilus-view-item.h"
 
 struct _NautilusLabelCell
 {
@@ -80,7 +83,7 @@ nautilus_label_cell_init (NautilusLabelCell *self)
     GtkWidget *child;
 
     child = gtk_label_new (NULL);
-    adw_bin_set_child (ADW_BIN (self), child);
+    gtk_widget_set_parent (child, GTK_WIDGET (self));
     gtk_widget_set_valign (child, GTK_ALIGN_CENTER);
     gtk_widget_add_css_class (child, "dim-label");
     self->label = GTK_LABEL (child);
@@ -131,22 +134,28 @@ nautilus_label_cell_constructed (GObject *object)
 }
 
 static void
-nautilus_label_cell_finalize (GObject *object)
+nautilus_label_cell_dispose (GObject *object)
 {
     NautilusLabelCell *self = (NautilusLabelCell *) object;
 
-    g_object_unref (self->item_signal_group);
-    G_OBJECT_CLASS (nautilus_label_cell_parent_class)->finalize (object);
+    g_clear_object (&self->item_signal_group);
+    if (self->label)
+    {
+        gtk_widget_unparent (GTK_WIDGET (self->label));
+        self->label = NULL;
+    }
+    G_OBJECT_CLASS (nautilus_label_cell_parent_class)->dispose (object);
 }
 
 static void
 nautilus_label_cell_class_init (NautilusLabelCellClass *klass)
 {
     GObjectClass *object_class = G_OBJECT_CLASS (klass);
+    GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
     object_class->set_property = nautilus_label_cell_set_property;
     object_class->constructed = nautilus_label_cell_constructed;
-    object_class->finalize = nautilus_label_cell_finalize;
+    object_class->dispose = nautilus_label_cell_dispose;
 
     properties[PROP_COLUMN] = g_param_spec_object ("column",
                                                    "", "",
@@ -154,6 +163,8 @@ nautilus_label_cell_class_init (NautilusLabelCellClass *klass)
                                                    G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
 
     g_object_class_install_properties (object_class, N_PROPS, properties);
+
+    gtk_widget_class_set_layout_manager_type (widget_class, GTK_TYPE_BIN_LAYOUT);
 }
 
 NautilusViewCell *
