@@ -126,10 +126,8 @@ on_ping_finished (GObject      *object,
                   GAsyncResult *res,
                   gpointer      user_data)
 {
-    g_autoptr (GVariant) variant = NULL;
     g_autoptr (GError) error = NULL;
-
-    variant = g_dbus_proxy_call_finish (G_DBUS_PROXY (object), res, &error);
+    g_autoptr (GVariant) variant = g_dbus_proxy_call_finish (G_DBUS_PROXY (object), res, &error);
 
     if (error == NULL)
     {
@@ -353,16 +351,16 @@ previewer_selection_event (GDBusConnection *connection,
         return;
     }
 
-    NautilusView *view = nautilus_window_slot_get_current_view (current_slot);
+    NautilusFilesView *view = nautilus_window_slot_get_current_view (current_slot);
     GtkDirectionType direction;
 
-    if (!NAUTILUS_IS_FILES_VIEW (view))
+    if (view == NULL)
     {
         return;
     }
 
     g_variant_get (parameters, "(u)", &direction);
-    nautilus_files_view_preview_selection_event (NAUTILUS_FILES_VIEW (view), direction);
+    nautilus_files_view_preview_selection_event (view, direction);
 }
 
 void
@@ -390,14 +388,13 @@ nautilus_previewer_teardown (GDBusConnection *connection)
 gboolean
 nautilus_previewer_is_visible (void)
 {
-    g_autoptr (GVariant) variant = NULL;
-
     if (!ensure_previewer_proxy ())
     {
         return FALSE;
     }
 
-    variant = g_dbus_proxy_get_cached_property (previewer_proxy, "Visible");
+    g_autoptr (GVariant) variant = g_dbus_proxy_get_cached_property (previewer_proxy, "Visible");
+
     if (variant)
     {
         return g_variant_get_boolean (variant);
