@@ -31,8 +31,8 @@
 #include "nautilus-query.h"
 #include "nautilus-scheme.h"
 #include "nautilus-search-directory-file.h"
-#include "nautilus-search-engine-model.h"
 #include "nautilus-search-engine.h"
+#include "nautilus-search-hit.h"
 #include "nautilus-search-provider.h"
 
 struct _NautilusSearchDirectory
@@ -44,13 +44,13 @@ struct _NautilusSearchDirectory
     NautilusSearchEngine *engine;
 
     gboolean search_running;
-    /* When the search directory is stopped or cancelled, we migth wait
+    /* When the search directory is stopped or cancelled, we might wait
      * until all data and signals from previous search are stopped and removed
      * from the search engine. While this situation happens we don't want to connect
      * clients to our signals, and we will wait until the search data and signals
      * are valid and ready.
      * The worst thing that can happens if we don't do this is that new clients
-     * migth get the information of old searchs if they are waiting_for_file_list.
+     * might get the information of old searches if they are waiting_for_file_list.
      * But that shouldn't be a big deal since old clients have the old information.
      * But anyway it's currently unused for this case since the only client is
      * nautilus-view and is not waiting_for_file_list :) .
@@ -67,8 +67,6 @@ struct _NautilusSearchDirectory
     GList *callback_list;
     GList *pending_callback_list;
 
-    GBinding *binding;
-
     NautilusDirectory *base_model;
 };
 
@@ -115,12 +113,6 @@ G_DEFINE_TYPE_WITH_CODE (NautilusSearchDirectory, nautilus_search_directory, NAU
 
 static GParamSpec *properties[NUM_PROPERTIES] = { NULL, };
 
-static void search_engine_hits_added (NautilusSearchEngine    *engine,
-                                      GList                   *hits,
-                                      NautilusSearchDirectory *self);
-static void search_engine_error (NautilusSearchEngine    *engine,
-                                 const char              *error,
-                                 NautilusSearchDirectory *self);
 static void search_callback_file_ready_callback (NautilusFile *file,
                                                  gpointer      data);
 static void file_changed (NautilusFile            *file,
@@ -156,43 +148,28 @@ reset_file_list (NautilusSearchDirectory *self)
     g_hash_table_remove_all (self->files_hash);
 }
 
-static void
-set_hidden_files (NautilusSearchDirectory *self)
+static gboolean
+is_monitoring_hidden_files (NautilusSearchDirectory *self)
 {
-    GList *l;
-    SearchMonitor *monitor;
-    gboolean monitor_hidden = FALSE;
-
-    for (l = self->monitor_list; l != NULL; l = l->next)
+    for (GList *l = self->monitor_list; l != NULL; l = l->next)
     {
-        monitor = l->data;
-        monitor_hidden |= monitor->monitor_hidden_files;
+        SearchMonitor *monitor = l->data;
 
-        if (monitor_hidden)
+        if (monitor->monitor_hidden_files)
         {
-            break;
+            return TRUE;
         }
     }
 
-    nautilus_query_set_show_hidden_files (self->query, monitor_hidden);
+    return FALSE;
 }
 
 static void
 start_search (NautilusSearchDirectory *self)
 {
-    NautilusSearchEngineModel *model_provider;
-
-    if (!self->query)
-    {
-        return;
-    }
-
-    if (self->search_running)
-    {
-        return;
-    }
-
-    if (!self->monitor_list && !self->pending_callback_list)
+    if (self->query == NULL ||
+        self->search_running ||
+        (self->monitor_list == NULL && self->pending_callback_list == NULL))
     {
         return;
     }
@@ -201,16 +178,12 @@ start_search (NautilusSearchDirectory *self)
     self->search_running = TRUE;
     self->search_ready_and_valid = FALSE;
 
-    set_hidden_files (self);
-    nautilus_search_provider_set_query (NAUTILUS_SEARCH_PROVIDER (self->engine),
-                                        self->query);
-
-    model_provider = nautilus_search_engine_get_model_provider (self->engine);
-    nautilus_search_engine_model_set_model (model_provider, self->base_model);
+    nautilus_query_set_show_hidden_files (self->query,
+                                          is_monitoring_hidden_files (self));
 
     reset_file_list (self);
-
-    nautilus_search_provider_start (NAUTILUS_SEARCH_PROVIDER (self->engine));
+    nautilus_search_provider_start (NAUTILUS_SEARCH_PROVIDER (self->engine),
+                                    self->query);
 }
 
 static void
@@ -231,12 +204,8 @@ static void
 file_changed (NautilusFile            *file,
               NautilusSearchDirectory *self)
 {
-    GList list;
-
-    list.data = file;
-    list.next = NULL;
-
-    nautilus_directory_emit_files_changed (NAUTILUS_DIRECTORY (self), &list);
+    nautilus_directory_emit_files_changed (NAUTILUS_DIRECTORY (self),
+                                           &(NautilusFileList){ .data = file });
 }
 
 static void
@@ -507,7 +476,7 @@ search_call_when_ready (NautilusDirectory         *directory,
     {
         /* Add it to the pending callback list, which will be
          * processed when the directory has valid data from the new
-         * search and all data and signals from previous searchs is removed. */
+         * search and all data and signals from previous search is removed. */
         self->pending_callback_list =
             g_list_prepend (self->pending_callback_list, search_callback);
 
@@ -602,10 +571,10 @@ on_search_directory_search_ready_and_valid (NautilusSearchDirectory *self)
 
 static void
 search_engine_hits_added (NautilusSearchEngine    *engine,
-                          GList                   *hits,
+                          GPtrArray               *transferred_hits,
                           NautilusSearchDirectory *self)
 {
-    GList *hit_list;
+    g_autoptr (GPtrArray) hits = transferred_hits;
     GList *file_list;
     NautilusFile *file;
     g_autoptr (GDateTime) now = g_date_time_new_now_local ();
@@ -613,15 +582,16 @@ search_engine_hits_added (NautilusSearchEngine    *engine,
     GList *monitor_list;
 
     file_list = NULL;
+    g_autoptr (GFile) query_location = nautilus_search_directory_get_search_location (self);
 
-    for (hit_list = hits; hit_list != NULL; hit_list = hit_list->next)
+    for (guint i = 0; i < hits->len; i++)
     {
-        NautilusSearchHit *hit = hit_list->data;
+        NautilusSearchHit *hit = hits->pdata[i];
         const char *uri;
 
         uri = nautilus_search_hit_get_uri (hit);
 
-        nautilus_search_hit_compute_scores (hit, now, self->query);
+        nautilus_search_hit_compute_scores (hit, now, query_location);
 
         file = nautilus_file_get_by_uri (uri);
         nautilus_file_set_search_relevance (file, nautilus_search_hit_get_relevance (hit));
@@ -933,7 +903,7 @@ nautilus_search_directory_init (NautilusSearchDirectory *self)
     self->query = NULL;
     self->files_hash = g_hash_table_new (g_direct_hash, g_direct_equal);
 
-    self->engine = nautilus_search_engine_new ();
+    self->engine = nautilus_search_engine_new (NAUTILUS_SEARCH_TYPE_FOLDER);
     search_connect_engine (self);
 }
 
@@ -974,10 +944,9 @@ nautilus_search_directory_class_init (NautilusSearchDirectoryClass *class)
 static void
 update_base_model (NautilusSearchDirectory *self)
 {
-    g_autoptr (GFile) query_location = NULL;
+    g_autoptr (GFile) query_location = nautilus_search_directory_get_search_location (self);
     g_autoptr (NautilusDirectory) base_model = NULL;
 
-    query_location = self->query != NULL ? nautilus_query_get_location (self->query) : NULL;
     base_model = nautilus_directory_get (query_location);
 
     if (self->base_model == base_model)
@@ -990,10 +959,15 @@ update_base_model (NautilusSearchDirectory *self)
 
     if (self->base_model != NULL)
     {
+        nautilus_search_engine_set_search_type (self->engine, NAUTILUS_SEARCH_TYPE_FOLDER);
         nautilus_directory_file_monitor_add (base_model, &self->base_model,
                                              TRUE, NAUTILUS_FILE_ATTRIBUTE_INFO,
                                              NULL, NULL);
     }
+    else
+    {
+        nautilus_search_engine_set_search_type (self->engine, NAUTILUS_SEARCH_TYPE_GLOBAL);
+    }
 }
 
 char *
@@ -1012,15 +986,6 @@ nautilus_search_directory_set_query (NautilusSearchDirectory *self,
 
     if (g_set_object (&self->query, query))
     {
-        g_clear_pointer (&self->binding, g_binding_unbind);
-
-        if (query)
-        {
-            self->binding = g_object_bind_property (self->engine, "running",
-                                                    query, "searching",
-                                                    G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
-        }
-
         g_object_notify_by_pspec (G_OBJECT (self), properties[PROP_QUERY]);
     }
 
@@ -1040,3 +1005,16 @@ nautilus_search_directory_get_query (NautilusSearchDirectory *self)
 {
     return self->query;
 }
+
+GFile *
+nautilus_search_directory_get_search_location (NautilusSearchDirectory *self)
+{
+    if (self->query != NULL)
+    {
+        return nautilus_query_get_location (self->query);
+    }
+    else
+    {
+        return NULL;
+    }
+}
