@@ -38,15 +38,16 @@
 #include <gdk/wayland/gdkwayland.h>
 #endif
 
-#include "gtk/nautilusgtkplacessidebarprivate.h"
-
 #include "nautilus-application.h"
+#include "nautilus-bookmark.h"
 #include "nautilus-bookmark-list.h"
 #include "nautilus-clipboard.h"
 #include "nautilus-dnd.h"
 #include "nautilus-enums.h"
+#include "nautilus-file.h"
 #include "nautilus-file-operations.h"
 #include "nautilus-file-undo-manager.h"
+#include "nautilus-file-undo-operations.h"
 #include "nautilus-file-utilities.h"
 #include "nautilus-global-preferences.h"
 #include "nautilus-metadata.h"
@@ -56,6 +57,7 @@
 #include "nautilus-progress-indicator.h"
 #include "nautilus-scheme.h"
 #include "nautilus-shortcut-manager.h"
+#include "nautilus-sidebar.h"
 #include "nautilus-signaller.h"
 #include "nautilus-toolbar.h"
 #include "nautilus-trash-monitor.h"
@@ -93,7 +95,7 @@ struct _NautilusWindow
     GtkWidget *split_view;
 
     /* Side Pane */
-    GtkWidget *places_sidebar;     /* the actual GtkPlacesSidebar */
+    NautilusSidebar *places_sidebar;
     GVolume *selected_volume;     /* the selected volume in the sidebar popup callback */
     GFile *selected_file;     /* the selected file in the sidebar popup callback */
 
@@ -194,7 +196,7 @@ action_go_home (GSimpleAction *action,
     window = NAUTILUS_WINDOW (user_data);
     home = g_file_new_for_path (g_get_home_dir ());
 
-    nautilus_window_open_location_full (window, home, 0, NULL, NULL, NULL);
+    nautilus_window_open_location_full (window, home, 0, NULL, NULL);
 
     g_object_unref (home);
 }
@@ -349,16 +351,6 @@ tab_view_notify_selected_page_cb (AdwTabView     *tab_view,
     nautilus_window_set_active_slot (window, slot);
 }
 
-static void
-connect_slot (NautilusWindow     *window,
-              NautilusWindowSlot *slot)
-{
-    g_signal_connect_swapped (slot, "notify::allow-stop",
-                              G_CALLBACK (update_cursor), window);
-    g_signal_connect (slot, "notify::location",
-                      G_CALLBACK (on_slot_location_changed), window);
-}
-
 static void
 disconnect_slot (NautilusWindow     *window,
                  NautilusWindowSlot *slot)
@@ -366,18 +358,6 @@ disconnect_slot (NautilusWindow     *window,
     g_signal_handlers_disconnect_by_data (slot, window);
 }
 
-static NautilusWindowSlot *
-nautilus_window_create_and_init_slot (NautilusWindow    *window,
-                                      NautilusOpenFlags  flags)
-{
-    NautilusWindowSlot *slot;
-
-    slot = nautilus_window_slot_new (NAUTILUS_MODE_BROWSE);
-    nautilus_window_initialize_slot (window, slot, flags);
-
-    return slot;
-}
-
 static void
 on_update_page_tooltip (NautilusWindowSlot *slot,
                         GParamSpec         *pspec,
@@ -408,20 +388,20 @@ on_update_page_tooltip (NautilusWindowSlot *slot,
     adw_tab_page_set_tooltip (page, escaped_name);
 }
 
-void
-nautilus_window_initialize_slot (NautilusWindow     *window,
-                                 NautilusWindowSlot *slot,
-                                 NautilusOpenFlags   flags)
+static NautilusWindowSlot *
+nautilus_window_create_and_init_slot (NautilusWindow *window)
 {
-    AdwTabPage *page, *current;
-
     g_assert (NAUTILUS_IS_WINDOW (window));
-    g_assert (NAUTILUS_IS_WINDOW_SLOT (slot));
 
-    connect_slot (window, slot);
+    NautilusWindowSlot *slot = nautilus_window_slot_new (NAUTILUS_MODE_BROWSE);
 
-    current = get_current_page (window);
-    page = adw_tab_view_add_page (window->tab_view, GTK_WIDGET (slot), current);
+    g_signal_connect_swapped (slot, "notify::allow-stop",
+                              G_CALLBACK (update_cursor), window);
+    g_signal_connect (slot, "notify::location",
+                      G_CALLBACK (on_slot_location_changed), window);
+
+    AdwTabPage *current = get_current_page (window);
+    AdwTabPage *page = adw_tab_view_add_page (window->tab_view, GTK_WIDGET (slot), current);
 
     g_object_bind_property (slot, "allow-stop",
                             page, "loading",
@@ -430,15 +410,16 @@ nautilus_window_initialize_slot (NautilusWindow     *window,
                             page, "title",
                             G_BINDING_SYNC_CREATE);
     g_signal_connect (slot, "notify::title", G_CALLBACK (on_update_page_tooltip), page);
+
+    return slot;
 }
 
 void
 nautilus_window_open_location_full (NautilusWindow     *window,
                                     GFile              *location,
                                     NautilusOpenFlags   flags,
-                                    GList              *selection,
-                                    NautilusWindowSlot *target_slot,
-                                    const char         *startup_id)
+                                    NautilusFileList   *selection,
+                                    NautilusWindowSlot *target_slot)
 {
     NautilusWindowSlot *active_slot;
 
@@ -453,22 +434,18 @@ nautilus_window_open_location_full (NautilusWindow     *window,
 
     if (target_slot == NULL || (flags & NAUTILUS_OPEN_FLAG_NEW_TAB) != 0)
     {
-        target_slot = nautilus_window_create_and_init_slot (window, flags);
+        target_slot = nautilus_window_create_and_init_slot (window);
     }
 
     /* Make the opened location the one active if we weren't ask for the
      * opposite, since it's the most usual use case */
     if (!(flags & NAUTILUS_OPEN_FLAG_DONT_MAKE_ACTIVE))
     {
-        if (startup_id)
-        {
-            gtk_window_set_startup_id (GTK_WINDOW (window), startup_id);
-        }
         gtk_window_present (GTK_WINDOW (window));
         nautilus_window_set_active_slot (window, target_slot);
     }
 
-    nautilus_window_slot_open_location_full (target_slot, location, flags, selection);
+    nautilus_window_slot_open_location_full (target_slot, location, selection);
 }
 
 static gboolean
@@ -524,7 +501,7 @@ nautilus_window_new_tab (NautilusWindow *window)
 
         nautilus_window_open_location_full (window, location,
                                             NAUTILUS_OPEN_FLAG_NEW_TAB,
-                                            NULL, NULL, NULL);
+                                            NULL, NULL);
         g_object_unref (location);
     }
 }
@@ -552,18 +529,18 @@ update_cursor (NautilusWindow *window)
 
 /* Callback used when the places sidebar needs to know the drag action to suggest */
 static GdkDragAction
-places_sidebar_drag_action_requested_cb (NautilusGtkPlacesSidebar *sidebar,
-                                         NautilusFile             *dest_file,
-                                         GList                    *source_file_list)
+places_sidebar_drag_action_requested_cb (NautilusSidebar *sidebar,
+                                         NautilusFile    *dest_file,
+                                         GList           *source_file_list)
 {
     return nautilus_dnd_get_preferred_action (dest_file, source_file_list->data);
 }
 #if 0 && NAUTILUS_DND_NEEDS_GTK4_REIMPLEMENTATION
 /* Callback used when the places sidebar needs us to pop up a menu with possible drag actions */
 static GdkDragAction
-places_sidebar_drag_action_ask_cb (NautilusGtkPlacesSidebar *sidebar,
-                                   GdkDragAction             actions,
-                                   gpointer                  user_data)
+places_sidebar_drag_action_ask_cb (NautilusSidebar *sidebar,
+                                   GdkDragAction    actions,
+                                   gpointer         user_data)
 {
     return nautilus_drag_drop_action_ask (GTK_WIDGET (sidebar), actions);
 }
@@ -590,11 +567,11 @@ build_uri_list_from_gfile_list (GSList *file_list)
 
 /* Callback used when the places sidebar has URIs dropped into it.  We do a normal file operation for them. */
 static void
-places_sidebar_drag_perform_drop_cb (NautilusGtkPlacesSidebar *sidebar,
-                                     GFile                    *dest_file,
-                                     GSList                   *source_file_list,
-                                     GdkDragAction             action,
-                                     gpointer                  user_data)
+places_sidebar_drag_perform_drop_cb (NautilusSidebar *sidebar,
+                                     GFile           *dest_file,
+                                     GSList          *source_file_list,
+                                     GdkDragAction    action,
+                                     gpointer         user_data)
 {
     char *dest_uri;
     GList *source_uri_list;
@@ -614,7 +591,6 @@ action_restore_tab (GSimpleAction *action,
                     gpointer       user_data)
 {
     NautilusWindow *window = NAUTILUS_WINDOW (user_data);
-    NautilusOpenFlags flags;
     g_autoptr (GFile) location = NULL;
     NautilusWindowSlot *slot;
     NautilusNavigationState *data;
@@ -624,15 +600,13 @@ action_restore_tab (GSimpleAction *action,
         return;
     }
 
-    flags = NAUTILUS_OPEN_FLAG_NEW_TAB | NAUTILUS_OPEN_FLAG_DONT_MAKE_ACTIVE;
-
     data = g_queue_pop_head (window->tab_data_queue);
 
     location = nautilus_bookmark_get_location (data->current_location_bookmark);
 
-    slot = nautilus_window_create_and_init_slot (window, flags);
+    slot = nautilus_window_create_and_init_slot (window);
 
-    nautilus_window_slot_open_location_full (slot, location, flags, NULL);
+    nautilus_window_slot_open_location_full (slot, location, NULL);
     nautilus_window_slot_restore_navigation_state (slot, data);
 
     free_navigation_state (data);
@@ -653,10 +627,10 @@ action_toggle_sidebar (GSimpleAction *action,
 static void
 nautilus_window_set_up_sidebar (NautilusWindow *window)
 {
-    nautilus_gtk_places_sidebar_set_open_flags (NAUTILUS_GTK_PLACES_SIDEBAR (window->places_sidebar),
-                                                (NAUTILUS_OPEN_FLAG_NORMAL
-                                                 | NAUTILUS_OPEN_FLAG_NEW_TAB
-                                                 | NAUTILUS_OPEN_FLAG_NEW_WINDOW));
+    nautilus_sidebar_set_open_flags (window->places_sidebar,
+                                     (NAUTILUS_OPEN_FLAG_NORMAL
+                                      | NAUTILUS_OPEN_FLAG_NEW_TAB
+                                      | NAUTILUS_OPEN_FLAG_NEW_WINDOW));
 
     g_signal_connect (window->places_sidebar, "drag-action-requested",
                       G_CALLBACK (places_sidebar_drag_action_requested_cb), window);
@@ -1002,7 +976,7 @@ tab_view_create_window_cb (AdwTabView     *tab_view,
     NautilusWindow *new_window;
 
     app = NAUTILUS_APPLICATION (g_application_get_default ());
-    new_window = nautilus_application_create_window (app);
+    new_window = nautilus_application_create_window (app, NULL);
     gtk_window_set_display (GTK_WINDOW (new_window),
                             gtk_widget_get_display (GTK_WIDGET (tab_view)));
 
@@ -1082,7 +1056,7 @@ extra_drag_drop_cb (AdwTabBar    *self,
                     gpointer      user_data)
 {
     NautilusWindowSlot *slot = NAUTILUS_WINDOW_SLOT (adw_tab_page_get_child (page));
-    NautilusFilesView *view = NAUTILUS_FILES_VIEW (nautilus_window_slot_get_current_view (slot));
+    NautilusFilesView *view = nautilus_window_slot_get_current_view (slot);
     GFile *target_location = nautilus_window_slot_get_location (slot);
     GdkDragAction action = adw_tab_bar_get_extra_drag_preferred_action (self);
 
@@ -1095,7 +1069,7 @@ const GActionEntry win_entries[] =
     { .name = "new-tab", .activate = action_new_tab },
     { .name = "undo", .activate = action_undo },
     { .name = "redo", .activate = action_redo },
-    /* Only accessible by shorcuts */
+    /* Only accessible by shortcuts */
     { .name = "close-current-view", .activate = action_close_current_view },
     { .name = "close-other-tabs", .activate = action_close_other_tabs },
     { .name = "go-home", .activate = action_go_home },
@@ -1128,7 +1102,7 @@ nautilus_window_initialize_actions (NautilusWindow *window)
 
     nautilus_application_set_accelerator (app, "win.undo", "<control>z");
     nautilus_application_set_accelerator (app, "win.redo", "<shift><control>z");
-    /* Only accessible by shorcuts */
+    /* Only accessible by shortcuts */
     nautilus_application_set_accelerator (app, "win.tab-move-left", "<shift><control>Page_Up");
     nautilus_application_set_accelerator (app, "win.tab-move-right", "<shift><control>Page_Down");
     nautilus_application_set_accelerator (app, "win.current-location-menu", "F10");
@@ -1240,7 +1214,7 @@ nautilus_window_constructed (GObject *self)
                              G_CALLBACK (nautilus_window_on_undo_changed), self,
                              G_CONNECT_AFTER);
 
-    /* Is required that the UI is constructed before initializating the actions, since
+    /* Is required that the UI is constructed before initializing the actions, since
      * some actions trigger UI widgets to show/hide. */
     nautilus_window_initialize_actions (window);
 }
@@ -1479,13 +1453,11 @@ void
 nautilus_window_back_or_forward_in_new_tab (NautilusWindow              *window,
                                             NautilusNavigationDirection  direction)
 {
-    GFile *location;
+    g_autoptr (GFile) location = NULL;
     NautilusWindowSlot *window_slot;
-    NautilusWindowSlot *new_slot;
     NautilusNavigationState *state;
 
     window_slot = nautilus_window_get_active_slot (window);
-    new_slot = nautilus_window_slot_new (NAUTILUS_MODE_BROWSE);
     state = nautilus_window_slot_get_navigation_state (window_slot);
 
     /* Manually fix up the back / forward lists and location.
@@ -1517,9 +1489,10 @@ nautilus_window_back_or_forward_in_new_tab (NautilusWindow              *window,
         }
     }
 
+    NautilusWindowSlot *new_slot = nautilus_window_create_and_init_slot (window);
+
     location = nautilus_bookmark_get_location (state->current_location_bookmark);
-    nautilus_window_initialize_slot (window, new_slot, NAUTILUS_OPEN_FLAG_NEW_TAB);
-    nautilus_window_slot_open_location_full (new_slot, location, 0, NULL);
+    nautilus_window_slot_open_location_full (new_slot, location, NULL);
     nautilus_window_slot_restore_navigation_state (new_slot, state);
 
     free_navigation_state (state);
@@ -1561,7 +1534,7 @@ nautilus_window_init (NautilusWindow *window)
 
     g_type_ensure (NAUTILUS_TYPE_NETWORK_ADDRESS_BAR);
     g_type_ensure (NAUTILUS_TYPE_TOOLBAR);
-    g_type_ensure (NAUTILUS_TYPE_GTK_PLACES_SIDEBAR);
+    g_type_ensure (NAUTILUS_TYPE_PLACES_SIDEBAR);
     g_type_ensure (NAUTILUS_TYPE_PROGRESS_INDICATOR);
     g_type_ensure (NAUTILUS_TYPE_SHORTCUT_MANAGER);
     gtk_widget_init_template (GTK_WIDGET (window));
