@@ -1,8 +1,11 @@
 #include <glib.h>
 #include <glib/gprintf.h>
 
+#include "nautilus-file.h"
+#include "nautilus-file-private.h"
 #include "src/nautilus-file-utilities.h"
 
+#include "test-utilities.h"
 
 static void
 test_has_large_enough_common_prefix (void)
@@ -351,62 +354,155 @@ test_smaller_min_length_and_doesnt_have_common_prefix (void)
     g_assert_null (actual);
 }
 
+static GList *
+get_files_for_names (const GStrv files_names)
+{
+    gsize len = g_strv_length (files_names);
+    GList *files = NULL;
+
+    for (gsize i = 0; i < len; i++)
+    {
+        gchar *name = files_names[i];
+        g_autofree gchar *uri = g_strconcat ("file:///", name, NULL);
+        NautilusFile *file = nautilus_file_get_by_uri (uri);
+
+        if (name[strlen (name) - 1] == G_DIR_SEPARATOR)
+        {
+            /* Info about the file type being a directory need to be set manually. */
+            file->details->type = G_FILE_TYPE_DIRECTORY;
+        }
+
+        files = g_list_prepend (files, file);
+    }
+
+    return files;
+}
+
+static void
+test_empty_file_list (void)
+{
+    g_autofree char *actual = nautilus_get_common_filename_prefix (NULL, 1);
+
+    g_assert_null (actual);
+}
+
+static void
+test_files (void)
+{
+    const GStrv names = (char *[])
+    {
+        "AB",
+        "AC",
+        NULL
+    };
+    g_autolist (NautilusFile) files = get_files_for_names (names);
+    g_autofree gchar *prefix = nautilus_get_common_filename_prefix (files, 1);
+
+    g_assert_nonnull (prefix);
+    g_assert_cmpstr (prefix, ==, "A");
+}
+
+static void
+test_directories (void)
+{
+    const GStrv names = (char *[])
+    {
+        "AB/",
+        "AC/",
+        NULL
+    };
+    g_autolist (NautilusFile) files = get_files_for_names (names);
+    g_autofree gchar *prefix = nautilus_get_common_filename_prefix (files, 1);
+
+    g_assert_nonnull (prefix);
+    g_assert_cmpstr (prefix, ==, "A");
+}
+
+static void
+test_files_and_directories (void)
+{
+    const GStrv names = (char *[])
+    {
+        "AB",
+        "AC/",
+        NULL
+    };
+    g_autolist (NautilusFile) files = get_files_for_names (names);
+    g_autofree gchar *prefix = nautilus_get_common_filename_prefix (files, 1);
+
+    g_assert_nonnull (prefix);
+    g_assert_cmpstr (prefix, ==, "A");
+}
 
 static void
 setup_test_suite (void)
 {
-    g_test_add_func ("/get-common-filename-prefix/1.0",
+    /* nautilus_get_common_filename_prefix_from_filenames () */
+    g_test_add_func ("/get-common-filename-prefix/string-list/1.0",
                      test_has_large_enough_common_prefix);
-    g_test_add_func ("/get-common-filename-prefix/1.1",
+    g_test_add_func ("/get-common-filename-prefix/string-list/1.1",
                      test_has_large_enough_common_prefix_with_spaces_in_middle);
-    g_test_add_func ("/get-common-filename-prefix/1.2",
+    g_test_add_func ("/get-common-filename-prefix/string-list/1.2",
                      test_has_large_enough_common_prefix_with_punctuation_in_middle);
-    g_test_add_func ("/get-common-filename-prefix/1.3",
+    g_test_add_func ("/get-common-filename-prefix/string-list/1.3",
                      test_has_large_enough_common_prefix_with_punctuation_in_middle_and_extension);
 
-    g_test_add_func ("/get-common-filename-prefix/2.0",
+    g_test_add_func ("/get-common-filename-prefix/string-list/2.0",
                      test_doesnt_have_large_enough_common_prefix);
-    g_test_add_func ("/get-common-filename-prefix/2.1",
+    g_test_add_func ("/get-common-filename-prefix/string-list/2.1",
                      test_doesnt_have_large_enough_common_prefix_completely_different_strings);
-    g_test_add_func ("/get-common-filename-prefix/2.2",
+    g_test_add_func ("/get-common-filename-prefix/string-list/2.2",
                      test_doesnt_have_large_enough_common_prefix_first_character_differs);
-    g_test_add_func ("/get-common-filename-prefix/2.3",
+    g_test_add_func ("/get-common-filename-prefix/string-list/2.3",
                      test_doesnt_have_large_enough_common_prefix_first_character_differs_longer_string);
 
-    g_test_add_func ("/get-common-filename-prefix/3.0",
+    g_test_add_func ("/get-common-filename-prefix/string-list/3.0",
                      test_has_large_enough_common_prefix_until_extension_removed);
 
-    g_test_add_func ("/get-common-filename-prefix/4.0",
+    g_test_add_func ("/get-common-filename-prefix/string-list/4.0",
                      test_extension_is_removed);
-    g_test_add_func ("/get-common-filename-prefix/4.1",
+    g_test_add_func ("/get-common-filename-prefix/string-list/4.1",
                      test_whitespace_is_removed);
-    g_test_add_func ("/get-common-filename-prefix/4.2",
+    g_test_add_func ("/get-common-filename-prefix/string-list/4.2",
                      test_whitespace_and_extension_are_removed);
-    g_test_add_func ("/get-common-filename-prefix/4.3",
+    g_test_add_func ("/get-common-filename-prefix/string-list/4.3",
                      test_punctuation_is_preserved);
 
-    g_test_add_func ("/get-common-filename-prefix/5.0",
+    g_test_add_func ("/get-common-filename-prefix/string-list/5.0",
                      test_unicode_on_inside);
-    g_test_add_func ("/get-common-filename-prefix/5.1",
+    g_test_add_func ("/get-common-filename-prefix/string-list/5.1",
                      test_unicode_on_outside);
-    g_test_add_func ("/get-common-filename-prefix/5.2",
+    g_test_add_func ("/get-common-filename-prefix/string-list/5.2",
                      test_unicode_whole_string);
-    g_test_add_func ("/get-common-filename-prefix/5.3",
+    g_test_add_func ("/get-common-filename-prefix/string-list/5.3",
                      test_unicode_extension);
-    g_test_add_func ("/get-common-filename-prefix/5.4",
+    g_test_add_func ("/get-common-filename-prefix/string-list/5.4",
                      test_unicode_with_punctuation);
 
-    g_test_add_func ("/get-common-filename-prefix/6.0",
+    g_test_add_func ("/get-common-filename-prefix/string-list/6.0",
                      test_many_strings);
-    g_test_add_func ("/get-common-filename-prefix/6.1",
+    g_test_add_func ("/get-common-filename-prefix/string-list/6.1",
                      test_many_strings_last_differs);
-    g_test_add_func ("/get-common-filename-prefix/6.2",
+    g_test_add_func ("/get-common-filename-prefix/string-list/6.2",
                      test_many_strings_first_differs);
 
-    g_test_add_func ("/get-common-filename-prefix/7.0",
+    g_test_add_func ("/get-common-filename-prefix/string-list/7.0",
                      test_smaller_min_length_and_does_have_common_prefix);
-    g_test_add_func ("/get-common-filename-prefix/7.1",
+    g_test_add_func ("/get-common-filename-prefix/string-list/7.1",
                      test_smaller_min_length_and_doesnt_have_common_prefix);
+
+    /* nautilus_get_common_filename_prefix () */
+    g_test_add_func ("/get-common-filename-prefix/file-list/1.0",
+                     test_empty_file_list);
+
+    g_test_add_func ("/get-common-filename-prefix/file-list/2.0",
+                     test_files);
+
+    g_test_add_func ("/get-common-filename-prefix/file-list/3.0",
+                     test_directories);
+
+    g_test_add_func ("/get-common-filename-prefix/file-list/4.0",
+                     test_files_and_directories);
 }
 
 int
@@ -416,6 +512,7 @@ main (int   argc,
     g_test_init (&argc, &argv, NULL);
     g_test_bug_base ("http://bugzilla.gnome.org/show_bug.cgi?id=747907");
     g_test_set_nonfatal_assertions ();
+    nautilus_ensure_extension_points ();
 
     setup_test_suite ();
 
